Table of contents
-----------------

* Introduction
* Features
* Schema.org types
* Requirements
* References


Introduction
------------

The **Schema.org Blueprints Starter Kit: Organization** module provides
a starting point for building out an Organization's content and information
model using Schema.org.

The starter kit includes the 
[Organization](https://schema/Organization) and 
[LocalBusiness](https://schema/LocalBusiness) types to distinguish between an 
[Organization](https://schema/Organization) being a conceptual entity and a
[LocalBusiness](https://schema/LocalBusiness) being a physical entity with 
a physical [Place](https://schema.org/Place). Site builders should use 
sub-typing to add additional specificity to
[Organization](https://schema/Organization) and
[LocalBusiness](https://schema/LocalBusiness) types. 

This starter kit leverages [inverseOf](https://schema.org/inverseOf)
relationships for [member](https://schema.org/member),
[employee](https://schema.org/employee),
[subOrganization](https://schema.org/subOrganization),
and [department](https://schema.org/department) to arrange an organization's
hierarchy and defines individual roles within an organization using the
[Role](https://schema.org/Role).

When an Organization and LocalBusiness needs dedicated access controls, 
authoring, or presentation, site builders should create a dedicated 
content type and use the 
[Convert Bundles](https://www.drupal.org/project/convert_bundles) module to 
switch an existing Organization content type to be a more specific sub-type.


Features
--------

- Provides default inverseOf relationships for entity references between 
  Organization, LocalBusiness, and Person content types.
- Defines the entity reference target bundles for Organization, LocalBusiness, 
  and Person relationships.
- Creates an Organization (and Local Business) view at /organization with a shortcut.
- Creates Entity View Attachments (EVA) for Organizations and Local Businesses
  to manage and add sub-organizations, departments, members, and employees.


Schema.org types
----------------

Below are the Schema.org types created by this starter kit.

**Person** (node:Person)  
A person (alive, dead, undead, or fictional).  
<https://schema.org/Person>

```mermaid
flowchart TB

Person((Person))
click Person "https://schema.org/Person"
style Person fill:#ffaacc,stroke:#333,stroke-width:4px;

Organization[Organization]
click Organization "https://schema.org/Organization"

LocalBusiness[LocalBusiness]
click LocalBusiness "https://schema.org/LocalBusiness"

Person --> |"memberOf (Role)"| Organization
Organization --> |"member (Role)"| Person
Person --> |"worksFor (Role)"| LocalBusiness
LocalBusiness --> |"employee (Role)"| Person
```

**Organization** (node:Organization)  
An organization such as a school, NGO, corporation, club, etc.  
<https://schema.org/Organization>

```mermaid
flowchart TB

Person[Person]
click Person "https://schema.org/Person"

Organization((Organization))
click Organization "https://schema.org/Organization"
style Organization fill:#ffaacc,stroke:#333,stroke-width:4px;

OrganizationChild[Organization]
click OrganizationChild "https://schema.org/Organization"

LocalBusiness[LocalBusiness]
click LocalBusiness "https://schema.org/LocalBusiness"

Organization ---> |subOrganization| OrganizationChild
OrganizationChild ---> |parentOrganization| Organization
Organization ---> |subOrganization| LocalBusiness
LocalBusiness ---> |parentOrganization| Organization
Person --> |memberOf| Organization
Organization --> |member| Person
```

**Local Business** (node:LocalBusiness)  
A particular physical business or branch of an organization.  
<https://schema.org/LocalBusiness>

```mermaid
flowchart TB

Organization[Organization]
click Organization "https://schema.org/Organization"

LocalBusiness((LocalBusiness))
click LocalBusiness "https://schema.org/LocalBusiness"
style LocalBusiness fill:#ffaacc,stroke:#333,stroke-width:4px;

LocalBusinessChild[LocalBusiness]
click LocalBusinessChild "https://schema.org/LocalBusiness"

Person[Person]
click Person "https://schema.org/Person"

Organization ---> |subOrganization| LocalBusiness
LocalBusiness ---> |parentOrganization| Organization

LocalBusiness ---> |department| LocalBusinessChild
LocalBusinessChild ---> |parentOrganization| LocalBusiness

Person --> |worksFor| LocalBusiness
LocalBusiness --> |employee| Person
```

Requirements
------------

**Sub-modules**

- **[Schema.org Blueprints Automatic Entity Labels](https://git.drupalcode.org/project/schemadotorg/-/tree/1.0.x/modules/schemadotorg_auto_entitylabel)**  
  Creates automatic entity label settings for Schema.org types.  
  _Used by Person content type to concat the person's first and last name._ 

- **[Schema.org Blueprints Corresponding Entity References](https://git.drupalcode.org/project/schemadotorg/-/tree/1.0.x/modules/schemdotorg_cer)**  
  Improves https://inverseOf support using the Corresponding Entity References module.  
  _Used by https://schema.org/inversOf relationships._

- **[Schema.org Blueprints Entity Prepopulate](https://git.drupalcode.org/project/schemadotorg/-/tree/1.0.x/modules/schemadotorg_epp)**  
  Configures and manages entity prepopulation for Schema.org relationships (i.e. entity references).
  _Used to prepopulate entity references via node links._

- **[Schema.org Blueprints Diagram](https://git.drupalcode.org/project/schemadotorg/-/tree/1.0.x/modules/schemadotorg_diagram)**  
  Provides a CSV export of Schema.org type mappings.  
  _Diagrams organization to person relationships._

- **[Schema.org Blueprints Role](https://git.drupalcode.org/project/schemadotorg/-/tree/1.0.x/modules/schemadotorg_role)**    
  Manages roles (https://schema.org/Role) for Schema.org properties.
  _Defines member and employee roles in an organization._

- **[Schema.org Blueprints Starter Kit (API)](https://git.drupalcode.org/project/schemadotorg/-/tree/1.0.x/modules/schemadotorg_starterkit)**  
  Provides an API for starter kits to create Schema.org types.

- **[Schema.org Blueprints Subtype](https://git.drupalcode.org/project/schemadotorg/-/tree/1.0.x/modules/schemadotorg_subtype)**  
  Subtypes allow more specificity without having to create dedicated entity types for every appropriate Schema.org type.

**Contribute modules**

- **[Automatic Entity Labels](https://drupal.org/project/auto_entitylabel)**  
  Allows hiding of entity label fields and automatic label creation.

- **[Corresponding Entity References](https://www.drupal.org/project/cer)**        
  Allows users to create two-way references between entities.

- **[Configuration Rewrite](https://drupal.org/project/config_rewrite)**  
  Rewrites existing configuration on module installation via using a "rewrite" folder in the config directory.

- **[Entity Reference Override](https://drupal.org/project/entity_reference_override)**    
  Entity reference with overridable title.  
  _Captures a https://schema.org/Person https://schema.org/Role._


References
----------

- @see /admin/reports/schemadotorg/docs/references#Organization
